@@ -6,16 +6,14 @@ IBusLookupTable *ibus_chewing_lookup_table_new(ChewingContext *context) {
     guint size = 10;
     gboolean cursorShow = TRUE;
     gboolean wrapAround = TRUE;
-    IBusLookupTable *iTable =
-        ibus_lookup_table_new(size, 0, cursorShow, wrapAround);
+    IBusLookupTable *iTable = ibus_lookup_table_new(size, 0, cursorShow, wrapAround);
 
     ibus_chewing_lookup_table_resize(iTable, context);
 
     return iTable;
 }
 
-void ibus_chewing_lookup_table_resize(IBusLookupTable *iTable,
-                                      ChewingContext *context) {
+void ibus_chewing_lookup_table_resize(IBusLookupTable *iTable, ChewingContext *context) {
     gint selKSym[MAX_SELKEY];
     g_autoptr(GSettings) settings = g_settings_new(QUOTE_ME(PROJECT_SCHEMA_ID));
     g_autofree char *selKeyStr = g_settings_get_string(settings, "sel-keys");
@@ -34,8 +32,7 @@ void ibus_chewing_lookup_table_resize(IBusLookupTable *iTable,
         for (i = 0; i < len; i++) {
             selKSym[i] = (gint)selKeyStr[i];
 
-            iText = g_object_ref_sink(
-                ibus_text_new_from_printf("%c.", toupper(selKeyStr[i])));
+            iText = g_object_ref_sink(ibus_text_new_from_printf("%c.", toupper(selKeyStr[i])));
             ibus_lookup_table_set_label(iTable, i, iText);
             g_object_unref(iText);
         }
@@ -43,14 +40,12 @@ void ibus_chewing_lookup_table_resize(IBusLookupTable *iTable,
     chewing_set_candPerPage(context, len);
     chewing_set_selKey(context, selKSym, len);
 
-    gboolean verticalLookupTable =
-        g_settings_get_boolean(settings, "vertical-lookup-table");
+    gboolean verticalLookupTable = g_settings_get_boolean(settings, "vertical-lookup-table");
 
     ibus_lookup_table_set_orientation(iTable, verticalLookupTable);
 }
 
-guint ibus_chewing_lookup_table_update(IBusLookupTable *iTable,
-                                       ChewingContext *context) {
+guint ibus_chewing_lookup_table_update(IBusLookupTable *iTable, ChewingContext *context) {
     IBusText *iText = NULL;
     gint i;
     gint choicePerPage = chewing_cand_ChoicePerPage(context);
@@ -70,7 +65,7 @@ guint ibus_chewing_lookup_table_update(IBusLookupTable *iTable,
 
             iText = g_object_ref_sink(ibus_text_new_from_string(candidate));
             ibus_lookup_table_append_candidate(iTable, iText);
-            g_free(candidate);
+            chewing_free(candidate);
             g_object_unref(iText);
         } else {
             break;
